@@ -10,6 +10,8 @@
 #include <QLocale>
 #include <QObject>
 
+#include <unicode/tznames.h>
+
 class TimezonesI18n : public QObject
 {
     Q_OBJECT
@@ -18,11 +20,12 @@ public:
     explicit TimezonesI18n(QObject *parent = nullptr);
     Q_INVOKABLE QString i18nContinents(const QString &continent);
     Q_INVOKABLE QString i18nCountry(QLocale::Country country);
+    Q_INVOKABLE QString i18nCity(const QString &timezoneId);
 
 private:
     void init();
 
     QHash<QString, QString> m_i18nContinents;
-    QHash<QLocale::Country, QString> m_i18nCountries;
+    QScopedPointer<icu::TimeZoneNames> m_tzNames;
     bool m_isInitialized;
 };
