@@ -8,6 +8,7 @@
 #include "appsmodel.h"
 #include "actionlist.h"
 #include "rootmodel.h"
+#include "sectionsmodel.h"
 
 #include <QCollator>
 #include <QDebug>
@@ -31,6 +32,7 @@ AppsModel::AppsModel(const QString &entryPath, bool paginate, int pageSize, bool
     , m_showTopLevelItems(false)
     , m_appletInterface(nullptr)
     , m_autoPopulate(true)
+    , m_sectionList(new SectionsModel(this))
     , m_description(i18n("Applications"))
     , m_entryPath(entryPath)
     , m_staticEntryList(false)
@@ -55,6 +57,7 @@ AppsModel::AppsModel(const QList<AbstractEntry *> &entryList, bool deleteEntries
     , m_showTopLevelItems(false)
     , m_appletInterface(nullptr)
     , m_autoPopulate(true)
+    , m_sectionList(new SectionsModel(this))
     , m_description(i18n("Applications"))
     , m_entryPath(QString())
     , m_staticEntryList(true)
@@ -188,6 +191,7 @@ bool AppsModel::trigger(int row, const QString &actionId, const QVariant &argume
     }
 
     AbstractEntry *entry = m_entryList.at(row);
+    const QString hiddenConfigEntryName = QStringLiteral("hiddenApplications");
 
     if (actionId == QLatin1String("hideApplication") && entry->type() == AbstractEntry::RunnableType) {
         QObject *appletInterface = rootModel()->property("appletInterface").value<QObject *>();
@@ -196,19 +200,19 @@ bool AppsModel::trigger(int row, const QString &actionId, const QVariant &argume
             appletConfig = qobject_cast<QQmlPropertyMap *>(appletInterface->property("configuration").value<QObject *>());
         }
 
-        if (appletConfig && appletConfig->contains(QStringLiteral("hiddenApplications"))) {
-            QStringList hiddenApps = appletConfig->value(QStringLiteral("hiddenApplications")).toStringList();
+        if (appletConfig && appletConfig->contains(hiddenConfigEntryName)) {
+            QStringList hiddenApps = appletConfig->value(hiddenConfigEntryName).toStringList();
 
             KService::Ptr service = static_cast<const AppEntry *>(entry)->service();
 
             if (!hiddenApps.contains(service->menuId())) {
                 hiddenApps << service->menuId();
 
-                appletConfig->insert(QStringLiteral("hiddenApplications"), hiddenApps);
+                appletConfig->insert(hiddenConfigEntryName, hiddenApps);
                 QMetaObject::invokeMethod(appletConfig,
                                           "valueChanged",
                                           Qt::DirectConnection,
-                                          Q_ARG(QString, QStringLiteral("hiddenApplications")),
+                                          Q_ARG(QString, hiddenConfigEntryName),
                                           Q_ARG(QVariant, hiddenApps));
 
                 refresh();
@@ -225,19 +229,15 @@ bool AppsModel::trigger(int row, const QString &actionId, const QVariant &argume
             appletConfig = qobject_cast<QQmlPropertyMap *>(appletInterface->property("configuration").value<QObject *>());
         }
 
-        if (appletConfig && appletConfig->contains(QStringLiteral("hiddenApplications"))) {
-            QStringList hiddenApps = appletConfig->value(QStringLiteral("hiddenApplications")).toStringList();
+        if (appletConfig && appletConfig->contains(hiddenConfigEntryName)) {
+            QStringList hiddenApps = appletConfig->value(hiddenConfigEntryName).toStringList();
 
             for (const QString &app : std::as_const(m_hiddenEntries)) {
                 hiddenApps.removeOne(app);
             }
 
-            appletConfig->insert(QStringLiteral("hiddenApplications"), hiddenApps);
-            QMetaObject::invokeMethod(appletConfig,
-                                      "valueChanged",
-                                      Qt::DirectConnection,
-                                      Q_ARG(QString, QStringLiteral("hiddenApplications")),
-                                      Q_ARG(QVariant, hiddenApps));
+            appletConfig->insert(hiddenConfigEntryName, hiddenApps);
+            QMetaObject::invokeMethod(appletConfig, "valueChanged", Qt::DirectConnection, Q_ARG(QString, hiddenConfigEntryName), Q_ARG(QVariant, hiddenApps));
 
             m_hiddenEntries.clear();
 
@@ -254,26 +254,22 @@ bool AppsModel::trigger(int row, const QString &actionId, const QVariant &argume
             appletConfig = qobject_cast<QQmlPropertyMap *>(appletInterface->property("configuration").value<QObject *>());
         }
 
-        if (entry->type() == AbstractEntry::GroupType && appletConfig && appletConfig->contains(QStringLiteral("hiddenApplications"))) {
+        if (entry->type() == AbstractEntry::GroupType && appletConfig && appletConfig->contains(hiddenConfigEntryName)) {
             const AppsModel *appsModel = qobject_cast<const AppsModel *>(entry->childModel());
 
             if (!appsModel) {
                 return false;
             }
 
-            QStringList hiddenApps = appletConfig->value(QStringLiteral("hiddenApplications")).toStringList();
+            QStringList hiddenApps = appletConfig->value(hiddenConfigEntryName).toStringList();
 
             const QStringList hiddenEntries = appsModel->hiddenEntries();
             for (const QString &app : hiddenEntries) {
                 hiddenApps.removeOne(app);
             }
 
-            appletConfig->insert(QStringLiteral("hiddenApplications"), hiddenApps);
-            QMetaObject::invokeMethod(appletConfig,
-                                      "valueChanged",
-                                      Qt::DirectConnection,
-                                      Q_ARG(QString, QStringLiteral("hiddenApplications")),
-                                      Q_ARG(QVariant, hiddenApps));
+            appletConfig->insert(hiddenConfigEntryName, hiddenApps);
+            QMetaObject::invokeMethod(appletConfig, "valueChanged", Qt::DirectConnection, Q_ARG(QString, hiddenConfigEntryName), Q_ARG(QVariant, hiddenApps));
 
             refresh();
 
@@ -444,7 +440,7 @@ QStringList AppsModel::hiddenEntries() const
     return m_hiddenEntries;
 }
 
-QVariantList AppsModel::sections() const
+SectionsModel *AppsModel::sections() const
 {
     return m_sectionList;
 }
@@ -611,7 +607,7 @@ void AppsModel::refreshInternal()
 
 void AppsModel::refreshSectionList()
 {
-    m_sectionList.clear();
+    m_sectionList->clear();
 
     if (m_entryList.empty()) {
         Q_EMIT sectionsChanged();
@@ -619,21 +615,16 @@ void AppsModel::refreshSectionList()
     }
 
     // Insert one item so no need to check empty in the loop
-    m_sectionList.append(QVariantMap{
-        {QStringLiteral("section"), m_entryList.at(0)->group().toUpper()},
-        {QStringLiteral("firstIndex"), 0},
-    });
+    m_sectionList->append(m_entryList.at(0)->group().toUpper(), 0);
 
     for (int i = 1; i < m_entryList.size(); i++) {
         const QString sectionName = m_entryList.at(i)->group().toUpper();
-        if (m_sectionList.constLast().toMap()[QStringLiteral("section")].toString() == sectionName) {
+
+        if (m_sectionList->lastSection() == sectionName) {
             continue;
         }
 
-        m_sectionList.append(QVariantMap{
-            {QStringLiteral("section"), sectionName},
-            {QStringLiteral("firstIndex"), i},
-        });
+        m_sectionList->append(sectionName, i);
     }
 
     Q_EMIT sectionsChanged();
