@@ -9,6 +9,7 @@
 #include <Plasma/Applet>
 #include <Plasma/Containment>
 #include <Plasma/Corona>
+#include <PlasmaQuick/AppletQuickItem>
 
 #include <KActionCollection>
 
@@ -68,20 +69,20 @@ bool ContainmentInterface::mayAddLauncher(QObject *appletInterface, ContainmentI
     }
     case TaskManager: {
         if (!entryPath.isEmpty() && containment->pluginMetaData().pluginId() == QLatin1String("org.kde.panel")) {
-            const Plasma::Applet *taskManager = findTaskManagerApplet(containment);
+            auto *taskManager = findTaskManagerApplet(containment);
 
             if (!taskManager) {
                 return false;
             }
 
-            QQuickItem *rootItem = firstPlasmaGraphicObjectChild(taskManager);
+            auto *taskManagerQuickItem = PlasmaQuick::AppletQuickItem::itemForApplet(taskManager);
 
-            if (!rootItem) {
+            if (!taskManagerQuickItem) {
                 return false;
             }
 
             QVariant ret;
-            QMetaObject::invokeMethod(rootItem, "hasLauncher", Q_RETURN_ARG(QVariant, ret), Q_ARG(QVariant, QUrl::fromLocalFile(entryPath)));
+            QMetaObject::invokeMethod(taskManagerQuickItem, "hasLauncher", Q_RETURN_ARG(QVariant, ret), Q_ARG(QVariant, QUrl::fromLocalFile(entryPath)));
             return !ret.toBool();
         }
 
@@ -122,43 +123,41 @@ void ContainmentInterface::addLauncher(QObject *appletInterface, ContainmentInte
         const QStringList &containmentProvides = containment->pluginMetaData().value(QStringLiteral("X-Plasma-Provides"), QStringList());
 
         if (containmentProvides.contains(QLatin1String("org.kde.plasma.filemanagement"))) {
-            QQuickItem *rootItem = findPlasmaGraphicObjectChildIf(containment, [](QQuickItem *item) {
-                return item->objectName() == QLatin1String("folder");
-            });
+            auto *folderQuickItem = PlasmaQuick::AppletQuickItem::itemForApplet(containment);
 
-            if (!rootItem) {
+            if (!folderQuickItem) {
                 return;
             }
 
-            QMetaObject::invokeMethod(rootItem, "addLauncher", Q_ARG(QVariant, QUrl::fromLocalFile(entryPath)));
+            QMetaObject::invokeMethod(folderQuickItem, "addLauncher", Q_ARG(QVariant, QUrl::fromLocalFile(entryPath)));
         } else {
-            containment->createApplet(QStringLiteral("org.kde.plasma.icon"), QVariantList() << entryPath);
+            containment->createApplet(QStringLiteral("org.kde.plasma.icon"), QVariantList() << QUrl::fromLocalFile(entryPath));
         }
 
         break;
     }
     case Panel: {
         if (containment->pluginMetaData().pluginId() == QLatin1String("org.kde.panel")) {
-            containment->createApplet(QStringLiteral("org.kde.plasma.icon"), QVariantList() << entryPath);
+            containment->createApplet(QStringLiteral("org.kde.plasma.icon"), QVariantList() << QUrl::fromLocalFile(entryPath));
         }
 
         break;
     }
     case TaskManager: {
         if (containment->pluginMetaData().pluginId() == QLatin1String("org.kde.panel")) {
-            const Plasma::Applet *taskManager = findTaskManagerApplet(containment);
+            auto *taskManager = findTaskManagerApplet(containment);
 
             if (!taskManager) {
                 return;
             }
 
-            QQuickItem *rootItem = firstPlasmaGraphicObjectChild(taskManager);
+            auto *taskManagerQuickItem = PlasmaQuick::AppletQuickItem::itemForApplet(taskManager);
 
-            if (!rootItem) {
+            if (!taskManagerQuickItem) {
                 return;
             }
 
-            QMetaObject::invokeMethod(rootItem, "addLauncher", Q_ARG(QVariant, QUrl::fromLocalFile(entryPath)));
+            QMetaObject::invokeMethod(taskManagerQuickItem, "addLauncher", Q_ARG(QVariant, QUrl::fromLocalFile(entryPath)));
         }
 
         break;
@@ -202,31 +201,10 @@ bool ContainmentInterface::screenContainmentMutable(QObject *appletInterface)
 void ContainmentInterface::ensureMutable(Plasma::Containment *containment)
 {
     if (containment && containment->immutability() != Plasma::Types::Mutable) {
-        containment->actions()->action(QStringLiteral("lock widgets"))->trigger();
+        containment->internalAction(QStringLiteral("lock widgets"))->trigger();
     }
 }
 
-template<class UnaryPredicate>
-QQuickItem *ContainmentInterface::findPlasmaGraphicObjectChildIf(const Plasma::Applet *applet, UnaryPredicate predicate)
-{
-    QQuickItem *gObj = qobject_cast<QQuickItem *>(applet->property("_plasma_graphicObject").value<QObject *>());
-
-    if (!gObj) {
-        return nullptr;
-    }
-
-    const QList<QQuickItem *> children = gObj->childItems();
-    const auto found = std::find_if(children.cbegin(), children.cend(), predicate);
-    return found != children.cend() ? *found : nullptr;
-}
-
-QQuickItem *ContainmentInterface::firstPlasmaGraphicObjectChild(const Plasma::Applet *applet)
-{
-    return findPlasmaGraphicObjectChildIf(applet, [](QQuickItem *) {
-        return true;
-    });
-}
-
 Plasma::Applet *ContainmentInterface::findTaskManagerApplet(Plasma::Containment *containment)
 {
     const QList<Plasma::Applet *> applets = containment->applets();
