@@ -6,7 +6,7 @@
 */
 
 #pragma once
-#include <Plasma/DataEngine>
+#include <Plasma5Support/DataEngine>
 #include <QCache>
 #include <QMap>
 #include <QVariantMap>
@@ -16,12 +16,12 @@ class QTcpSocket;
  * This class evaluates the basic expressions given in the interface.
  */
 
-class DictEngine : public Plasma::DataEngine
+class DictEngine : public Plasma5Support::DataEngine
 {
     Q_OBJECT
 
 public:
-    DictEngine(QObject *parent, const QVariantList &args);
+    DictEngine(QObject *parent);
     ~DictEngine() override;
 
 protected:
