@@ -6,11 +6,11 @@
 
 #pragma once
 
-#include <Plasma/Service>
+#include <Plasma5Support/Service>
 
 class NotificationsEngine;
 
-class NotificationService : public Plasma::Service
+class NotificationService : public Plasma5Support::Service
 {
     Q_OBJECT
 
@@ -18,7 +18,7 @@ public:
     NotificationService(NotificationsEngine *parent, const QString &source);
 
 protected:
-    Plasma::ServiceJob *createJob(const QString &operation, QMap<QString, QVariant> &parameters) override;
+    Plasma5Support::ServiceJob *createJob(const QString &operation, QMap<QString, QVariant> &parameters) override;
 
 private:
     NotificationsEngine *m_notificationEngine;
