@@ -7,8 +7,9 @@
 
 #pragma once
 
-#include <KNSCore/EntryWrapper>
-#include <KQuickAddons/ManagedConfigModule>
+#include <KNSCore/Entry>
+#include <KQuickManagedConfigModule>
+#include <QAbstractItemModel>
 
 #include "cursorthemesettings.h"
 #include "launchfeedbacksettings.h"
@@ -27,7 +28,7 @@ namespace KIO
 class FileCopyJob;
 }
 
-class CursorThemeConfig : public KQuickAddons::ManagedConfigModule
+class CursorThemeConfig : public KQuickManagedConfigModule
 {
     Q_OBJECT
 
@@ -43,7 +44,7 @@ class CursorThemeConfig : public KQuickAddons::ManagedConfigModule
     Q_PROPERTY(int preferredSize READ preferredSize WRITE setPreferredSize NOTIFY preferredSizeChanged)
 
 public:
-    CursorThemeConfig(QObject *parent, const KPluginMetaData &data, const QVariantList &);
+    CursorThemeConfig(QObject *parent, const KPluginMetaData &data);
     ~CursorThemeConfig() override;
 
     void load() override;
@@ -89,7 +90,7 @@ Q_SIGNALS:
     void showErrorMessage(const QString &message);
 
 public Q_SLOTS:
-    void ghnsEntryChanged(KNSCore::EntryWrapper *entry);
+    void ghnsEntryChanged(const KNSCore::Entry &entry);
     void installThemeFromFile(const QUrl &url);
 
 private Q_SLOTS:
