@@ -4,6 +4,7 @@
     SPDX-FileCopyrightText: 2019 Cyril Rossi <cyril.rossi@enioka.com>
     SPDX-FileCopyrightText: 2021 Benjamin Port <benjamin.port@enioka.com>
     SPDX-FileCopyrightText: 2022 Dominic Hayes <ferenosdev@outlook.com>
+    SPDX-FileCopyrightText: 2023 Ismael Asensio <isma.af@gmail.com>
 
     SPDX-License-Identifier: LGPL-2.0-only
 */
@@ -28,8 +29,10 @@ public:
         Apply, // Apply the look and feel theme, i.e. change the active settings and set them up as new defaults. This is the default.
         Defaults // Only set up the options of the look and feel theme as new defaults without changing any active setting
     };
-    // Flags for storing values
-    enum AppearanceToApplyFlags {
+
+    enum ContentFlags {
+        Empty = 0,
+        // Appearance
         Colors = 1 << 0,
         WidgetStyle = 1 << 1,
         WindowDecoration = 1 << 2,
@@ -40,36 +43,37 @@ public:
         WindowSwitcher = 1 << 7,
         SplashScreen = 1 << 8,
         LockScreen = 1 << 9,
-        AppearanceSettings = (1 << 10) - 1, // Blanket switch - sets everything
+        Wallpaper = 1 << 10,
+        BorderSize = 1 << 11,
+        AppearanceSettings = (1 << 12) - 1, // All the contents within Appearance
+        // Layout
+        DesktopLayout = 1 << 16,
+        TitlebarLayout = 1 << 17,
+        WindowPlacement = 1 << 18,
+        ShellPackage = 1 << 19,
+        LayoutSettings = (1 << 20) - (1 << 16), // All the contents within Layout
+        // Maybe unused or deprecated?
+        RunCommand = 1 << 24,
+        LogOutScript = 1 << 25,
+        // General Flag combinations
+        KWinSettings = WindowSwitcher | WindowDecoration | WindowPlacement | TitlebarLayout | BorderSize,
+        AllSettings = (1 << 26) - 1,
     };
-    Q_DECLARE_FLAGS(AppearanceToApply, AppearanceToApplyFlags)
-    Q_FLAG(AppearanceToApply)
-    Q_PROPERTY(AppearanceToApply appearanceToApply READ appearanceToApply WRITE setAppearanceToApply NOTIFY appearanceToApplyChanged)
-
-    enum LayoutToApplyFlags {
-        DesktopLayout = 1 << 0,
-        TitlebarLayout = 1 << 1,
-        WindowPlacement = 1 << 2, // FIXME: Do we still want these three?
-        ShellPackage = 1 << 3,
-        DesktopSwitcher = 1 << 4,
-        LayoutSettings = (1 << 5) - 1,
-    };
-    Q_DECLARE_FLAGS(LayoutToApply, LayoutToApplyFlags)
-    Q_FLAG(LayoutToApply)
-    Q_PROPERTY(LayoutToApply layoutToApply READ layoutToApply WRITE setLayoutToApply NOTIFY layoutToApplyChanged)
+    Q_DECLARE_FLAGS(Contents, ContentFlags)
+    Q_FLAG(Contents)
 
     LookAndFeelManager(QObject *parent = nullptr);
 
     void setMode(Mode mode);
     /**
-     * Apply the theme represented by package, with oldPackage being the currently active package.
-     * Effects depend upon the Mode of this object. If Mode is Defaults, oldPackage is ignored.
+     * Apply the theme represented by @p package, with @p previousPackage being the currently active package.
+     * Effects depend upon the Mode of this object. If Mode is Defaults, @p previousPackage is ignored.
+     * @p applyMask filters the package contents that will be applied.
      */
-    void save(const KPackage::Package &package, const KPackage::Package &oldPackage);
-    AppearanceToApply appearanceToApply() const;
-    void setAppearanceToApply(AppearanceToApply value);
-    LayoutToApply layoutToApply() const;
-    void setLayoutToApply(LayoutToApply value);
+    void save(const KPackage::Package &package, const KPackage::Package &previousPackage, Contents applyMask = AllSettings);
+    bool remove(const KPackage::Package &package, Contents contentsMask = Empty);
+
+    Contents packageContents(const KPackage::Package &package) const;
 
     QString colorSchemeFile(const QString &schemeName) const;
 
@@ -83,9 +87,9 @@ public:
     void setLatteLayout(const QString &filepath, const QString &name);
     void setLockScreen(const QString &theme);
     void setWindowSwitcher(const QString &theme);
-    void setDesktopSwitcher(const QString &theme);
     void setWindowDecoration(const QString &library, const QString &theme, bool noPlugin);
     void setTitlebarLayout(const QString &leftbtns, const QString &rightbtns);
+    void setBorderSize(const QString &size);
     void setBorderlessMaximized(const QString &value);
     void setWindowPlacement(const QString &value);
     void setShellPackage(const QString &name);
@@ -102,8 +106,6 @@ public:
 
 Q_SIGNALS:
     void message();
-    void appearanceToApplyChanged();
-    void layoutToApplyChanged();
     void iconsChanged();
     void colorsChanged();
     void styleChanged(const QString &newStyle);
@@ -131,10 +133,8 @@ private:
     LookAndFeelData *const m_data;
     Mode m_mode = Mode::Apply;
     bool m_applyLatteLayout : 1;
-    AppearanceToApply m_appearanceToApply;
-    LayoutToApply m_layoutToApply;
     bool m_plasmashellChanged : 1;
     bool m_fontsChanged : 1;
 };
-Q_DECLARE_OPERATORS_FOR_FLAGS(LookAndFeelManager::AppearanceToApply)
-Q_DECLARE_OPERATORS_FOR_FLAGS(LookAndFeelManager::LayoutToApply)
+
+Q_DECLARE_OPERATORS_FOR_FLAGS(LookAndFeelManager::Contents)
