@@ -17,13 +17,11 @@
 #include "server.h"
 #include "client.h"
 #include "global.h"
-#include "kglobalaccel.h"
 #include "klocalizedstring.h"
 #include "ksmserver_debug.h"
 #include "ksmserverinterfaceadaptor.h"
 
 #include <config-ksmserver.h>
-#include <config-unix.h> // HAVE_LIMITS_H
 #include <config-workspace.h>
 #include <pwd.h>
 #include <sys/param.h>
@@ -36,19 +34,16 @@
 #include <sys/socket.h>
 #include <sys/un.h>
 
-#include <assert.h>
-#include <errno.h>
+#include <cassert>
+#include <cerrno>
+#include <climits>
+#include <csignal>
+#include <cstdlib>
+#include <cstring>
+#include <ctime>
 #include <fcntl.h>
-#include <signal.h>
-#include <stdlib.h>
-#include <string.h>
-#include <time.h>
 #include <unistd.h>
 
-#ifdef HAVE_LIMITS_H
-#include <limits.h>
-#endif
-
 #include <QAction>
 #include <QApplication>
 #include <QDBusConnection>
@@ -136,8 +131,9 @@ KSMServer *KSMServer::self()
 void KSMServer::startApplication(const QStringList &cmd, const QString &clientMachine, const QString &userId)
 {
     QStringList command = cmd;
-    if (command.isEmpty())
+    if (command.isEmpty()) {
         return;
+    }
     if (!userId.isEmpty()) {
         struct passwd *pw = getpwuid(getuid());
         if (pw != nullptr && userId != QString::fromLocal8Bit(pw->pw_name)) {
@@ -155,7 +151,7 @@ void KSMServer::startApplication(const QStringList &cmd, const QString &clientMa
     const QString app = command.takeFirst();
     const QStringList argList = command;
     auto *job = new KIO::CommandLauncherJob(app, argList);
-    auto apps = KApplicationTrader::query([&app](const KService::Ptr service) {
+    auto apps = KApplicationTrader::query([&app](const KService::Ptr &service) {
         const QString binary = KIO::DesktopExecParser::executablePath(service->exec());
         return !service->noDisplay() && !binary.isEmpty() && app.endsWith(binary);
     });
@@ -170,8 +166,9 @@ void KSMServer::startApplication(const QStringList &cmd, const QString &clientMa
  */
 void KSMServer::executeCommand(const QStringList &command)
 {
-    if (command.isEmpty())
+    if (command.isEmpty()) {
         return;
+    }
 
     KProcess::execute(command);
 }
@@ -182,14 +179,11 @@ static QTemporaryFile *remTempFile = nullptr;
 
 static IceListenObj *listenObjs = nullptr;
 int numTransports = 0;
-static bool only_local = 0;
+static bool only_local = false;
 
 static Bool HostBasedAuthProc(char * /*hostname*/)
 {
-    if (only_local)
-        return true;
-    else
-        return false;
+    return only_local;
 }
 
 Status KSMRegisterClientProc(SmsConn /* smsConn */, SmPointer managerData, char *previousId)
@@ -212,10 +206,9 @@ void KSMInteractDoneProc(SmsConn /* smsConn */, SmPointer managerData, Bool canc
 void KSMSaveYourselfRequestProc(SmsConn smsConn, SmPointer /* managerData */, int saveType, Bool shutdown, int interactStyle, Bool fast, Bool global)
 {
     if (shutdown) {
-        the_server->shutdown(fast ? KWorkSpace::ShutdownConfirmNo : KWorkSpace::ShutdownConfirmDefault,
-                             KWorkSpace::ShutdownTypeDefault,
-                             KWorkSpace::ShutdownModeDefault);
-    } else if (!global) {
+        qCWarning(KSMSERVER) << "Shutdown via ICE was called but not supported";
+    }
+    if (!global) {
         SmsSaveYourself(smsConn, saveType, false, interactStyle, fast);
         SmsSaveComplete(smsConn);
     }
@@ -236,8 +229,9 @@ void KSMSaveYourselfDoneProc(SmsConn /* smsConn */, SmPointer managerData, Bool
 void KSMCloseConnectionProc(SmsConn smsConn, SmPointer managerData, int count, char **reasonMsgs)
 {
     the_server->deleteClient((KSMClient *)managerData);
-    if (count)
+    if (count) {
         SmFreeReasons(count, reasonMsgs);
+    }
     IceConn iceConn = SmsGetIceConnection(smsConn);
     SmsCleanUp(smsConn);
     IceSetShutdownNegotiation(iceConn, false);
@@ -246,7 +240,7 @@ void KSMCloseConnectionProc(SmsConn smsConn, SmPointer managerData, int count, c
 
 void KSMSetPropertiesProc(SmsConn /* smsConn */, SmPointer managerData, int numProps, SmProp **props)
 {
-    KSMClient *client = (KSMClient *)managerData;
+    auto client = (KSMClient *)managerData;
     for (int i = 0; i < numProps; i++) {
         SmProp *p = client->property(props[i]->name);
         if (p) {
@@ -256,13 +250,14 @@ void KSMSetPropertiesProc(SmsConn /* smsConn */, SmPointer managerData, int numP
         client->properties.append(props[i]);
     }
 
-    if (numProps)
+    if (numProps) {
         free(props);
+    }
 }
 
 void KSMDeletePropertiesProc(SmsConn /* smsConn */, SmPointer managerData, int numProps, char **propNames)
 {
-    KSMClient *client = (KSMClient *)managerData;
+    auto client = (KSMClient *)managerData;
     for (int i = 0; i < numProps; i++) {
         SmProp *p = client->property(propNames[i]);
         if (p) {
@@ -274,8 +269,8 @@ void KSMDeletePropertiesProc(SmsConn /* smsConn */, SmPointer managerData, int n
 
 void KSMGetPropertiesProc(SmsConn smsConn, SmPointer managerData)
 {
-    KSMClient *client = (KSMClient *)managerData;
-    SmProp **props = new SmProp *[client->properties.count()];
+    auto client = (KSMClient *)managerData;
+    auto props = new SmProp *[client->properties.count()];
     int i = 0;
     foreach (SmProp *prop, client->properties)
         props[i++] = prop;
@@ -287,7 +282,7 @@ void KSMGetPropertiesProc(SmsConn smsConn, SmPointer managerData)
 class KSMListener : public QSocketNotifier
 {
 public:
-    KSMListener(IceListenObj obj)
+    explicit KSMListener(IceListenObj obj)
         : QSocketNotifier(IceGetListenConnectionNumber(obj), QSocketNotifier::Read)
         , listenObj(obj)
     {
@@ -299,7 +294,7 @@ public:
 class KSMConnection : public QSocketNotifier
 {
 public:
-    KSMConnection(IceConn conn)
+    explicit KSMConnection(IceConn conn)
         : QSocketNotifier(IceConnectionNumber(conn), QSocketNotifier::Read)
         , iceConn(conn)
     {
@@ -346,11 +341,11 @@ static void write_iceauth(FILE *addfp, FILE *removefp, IceAuthDataEntry *entry)
 
 Status SetAuthentication_local(int count, IceListenObj *listenObjs)
 {
-    int i;
-    for (i = 0; i < count; i++) {
+    for (int i = 0; i < count; i++) {
         char *prot = IceGetListenConnectionString(listenObjs[i]);
-        if (!prot)
+        if (!prot) {
             continue;
+        }
         char *host = strchr(prot, '/');
         char *sock = nullptr;
         if (host) {
@@ -377,11 +372,13 @@ Status SetAuthentication(int count, IceListenObj *listenObjs, IceAuthDataEntry *
     QTemporaryFile addTempFile;
     remTempFile = new QTemporaryFile;
 
-    if (!addTempFile.open() || !remTempFile->open())
+    if (!addTempFile.open() || !remTempFile->open()) {
         return 0;
+    }
 
-    if ((*authDataEntries = (IceAuthDataEntry *)malloc(count * 2 * sizeof(IceAuthDataEntry))) == nullptr)
+    if ((*authDataEntries = (IceAuthDataEntry *)malloc(count * 2 * sizeof(IceAuthDataEntry))) == nullptr) {
         return 0;
+    }
 
     FILE *addAuthFile = fopen(QFile::encodeName(addTempFile.fileName()).constData(), "r+");
     FILE *remAuthFile = fopen(QFile::encodeName(remTempFile->fileName()).constData(), "r+");
@@ -430,8 +427,9 @@ Status SetAuthentication(int count, IceListenObj *listenObjs, IceAuthDataEntry *
 void FreeAuthenticationData(int count, IceAuthDataEntry *authDataEntries)
 {
     /* Each transport has entries for ICE and XSMP */
-    if (only_local)
+    if (only_local) {
         return;
+    }
 
     for (int i = 0; i < count * 2; i++) {
         free(authDataEntries[i].network_id);
@@ -486,12 +484,12 @@ static void sighandler(int sig)
     }
 
     char ch = 0;
-    (void)::write(wake_up_socket, &ch, 1);
+    std::ignore = ::write(wake_up_socket, &ch, 1);
 }
 
 void KSMWatchProc(IceConn iceConn, IcePointer client_data, Bool opening, IcePointer *watch_data)
 {
-    KSMServer *ds = (KSMServer *)client_data;
+    auto ds = (KSMServer *)client_data;
 
     if (opening) {
         *watch_data = (IcePointer)ds->watchConnection(iceConn);
@@ -505,11 +503,11 @@ static Status KSMNewClientProc(SmsConn conn, SmPointer manager_data, unsigned lo
     *failure_reason_ret = nullptr;
 
     void *client = ((KSMServer *)manager_data)->newClient(conn);
-    if (client == NULL) {
+    if (!client) {
         const char *errstr = "Connection rejected: ksmserver is shutting down";
         qCWarning(KSMSERVER, "%s", errstr);
 
-        if ((*failure_reason_ret = (char *)malloc(strlen(errstr) + 1)) != NULL) {
+        if ((*failure_reason_ret = (char *)malloc(strlen(errstr) + 1)) != nullptr) {
             strcpy(*failure_reason_ret, errstr);
         }
         return 0;
@@ -558,11 +556,12 @@ KSMServer::KSMServer(InitFlags flags)
         }
     }
 
-    if (::socketpair(AF_UNIX, SOCK_STREAM | SOCK_CLOEXEC, 0, sockets) != 0)
+    if (::socketpair(AF_UNIX, SOCK_STREAM | SOCK_CLOEXEC, 0, sockets) != 0) {
         qFatal("Could not create socket pair, error %d (%s)", errno, strerror(errno));
+    }
     wake_up_socket = sockets[0];
-    QSocketNotifier *n = new QSocketNotifier(sockets[1], QSocketNotifier::Read, this);
-    qApp->connect(n, &QSocketNotifier::activated, &QApplication::quit);
+    auto notifier = new QSocketNotifier(sockets[1], QSocketNotifier::Read, this);
+    qApp->connect(notifier, &QSocketNotifier::activated, &QApplication::quit);
 
     new KSMServerInterfaceAdaptor(this);
     QDBusConnection::sessionBus().registerObject(QStringLiteral("/KSMServer"), this);
@@ -571,14 +570,15 @@ KSMServer::KSMServer(InitFlags flags)
 
     state = Idle;
     saveSession = false;
-    KConfigGroup config(KSharedConfig::openConfig(), "General");
+    KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("General"));
     clientInteracting = nullptr;
     xonCommand = config.readEntry("xonCommand", "xon");
 
     only_local = flags.testFlag(InitFlag::OnlyLocal);
 #ifdef HAVE__ICETRANSNOLISTEN
-    if (only_local)
+    if (only_local) {
         _IceTransNoListen("tcp");
+    }
 #else
     only_local = false;
 #endif
@@ -602,15 +602,16 @@ KSMServer::KSMServer(InitFlags flags)
         QString display = QString::fromLocal8Bit(::getenv("DISPLAY"));
         // strip the screen number from the display
         display.remove(QRegularExpression(QStringLiteral("\\.[0-9]+$")));
-        int i;
-        while ((i = display.indexOf(QLatin1Char(':'))) >= 0)
+        int i = 0;
+        while ((i = display.indexOf(QLatin1Char(':'))) >= 0) {
             display[i] = QLatin1Char('_');
-        while ((i = display.indexOf(QLatin1Char('/'))) >= 0)
+        }
+        while ((i = display.indexOf(QLatin1Char('/'))) >= 0) {
             display[i] = QLatin1Char('_');
+        }
 
         fName += '_' + display.toLocal8Bit();
-        FILE *f;
-        f = ::fopen(fName.data(), "w+");
+        FILE *f = ::fopen(fName.data(), "w+");
         if (!f) {
             qCWarning(KSMSERVER, "KSMServer: cannot open %s: %s", fName.data(), strerror(errno));
             qCWarning(KSMSERVER, "KSMServer: Aborting.");
@@ -632,16 +633,18 @@ KSMServer::KSMServer(InitFlags flags)
     }
 
     if (only_local) {
-        if (!SetAuthentication_local(numTransports, listenObjs))
+        if (!SetAuthentication_local(numTransports, listenObjs)) {
             qFatal("KSMSERVER: authentication setup failed.");
+        }
     } else {
-        if (!SetAuthentication(numTransports, listenObjs, &authDataEntries))
+        if (!SetAuthentication(numTransports, listenObjs, &authDataEntries)) {
             qFatal("KSMSERVER: authentication setup failed.");
+        }
     }
 
     IceAddConnectionWatch(KSMWatchProc, (IcePointer)this);
 
-    KSMListener *con;
+    KSMListener *con = nullptr;
     for (int i = 0; i < numTransports; i++) {
         fcntl(IceGetListenConnectionNumber(listenObjs[i]), F_SETFD, FD_CLOEXEC);
         con = new KSMListener(listenObjs[i]);
@@ -681,8 +684,9 @@ KSMServer::~KSMServer()
 
 void KSMServer::cleanUp()
 {
-    if (clean)
+    if (clean) {
         return;
+    }
     clean = true;
     IceFreeListenObjs(numTransports, listenObjs);
 
@@ -696,11 +700,13 @@ void KSMServer::cleanUp()
     QString display = QString::fromLocal8Bit(::getenv("DISPLAY"));
     // strip the screen number from the display
     display.remove(QRegularExpression(QStringLiteral("\\.[0-9]+$")));
-    int i;
-    while ((i = display.indexOf(QLatin1Char(':'))) >= 0)
+    int i = 0;
+    while ((i = display.indexOf(QLatin1Char(':'))) >= 0) {
         display[i] = QLatin1Char('_');
-    while ((i = display.indexOf(QLatin1Char('/'))) >= 0)
+    }
+    while ((i = display.indexOf(QLatin1Char('/'))) >= 0) {
         display[i] = QLatin1Char('_');
+    }
 
     fName += '_' + display.toLocal8Bit();
     ::unlink(fName.data());
@@ -712,7 +718,7 @@ void KSMServer::cleanUp()
 
 void *KSMServer::watchConnection(IceConn iceConn)
 {
-    KSMConnection *conn = new KSMConnection(iceConn);
+    auto conn = new KSMConnection(iceConn);
     connect(conn, &KSMConnection::activated, this, &KSMServer::processData);
     return (void *)conn;
 }
@@ -731,14 +737,15 @@ void KSMServer::ioError(IceConn /*iceConn*/)
 
 void KSMServer::processData(int /*socket*/)
 {
-    IceConn iceConn = ((KSMConnection *)sender())->iceConn;
+    auto iceConn = ((KSMConnection *)sender())->iceConn;
     IceProcessMessagesStatus status = IceProcessMessages(iceConn, nullptr, nullptr);
     if (status == IceProcessMessagesIOError) {
         IceSetShutdownNegotiation(iceConn, false);
         QList<KSMClient *>::iterator it = clients.begin();
         QList<KSMClient *>::iterator const itEnd = clients.end();
-        while ((it != itEnd) && *it && (SmsGetIceConnection((*it)->connection()) != iceConn))
+        while ((it != itEnd) && *it && (SmsGetIceConnection((*it)->connection()) != iceConn)) {
             ++it;
+        }
         if ((it != itEnd) && *it) {
             SmsConn smsConn = (*it)->connection();
             deleteClient(*it);
@@ -760,8 +767,9 @@ KSMClient *KSMServer::newClient(SmsConn conn)
 
 void KSMServer::deleteClient(KSMClient *client)
 {
-    if (!clients.contains(client)) // paranoia
+    if (!clients.contains(client)) { // paranoia
         return;
+    }
     clients.removeAll(client);
     clientsToKill.removeAll(client);
     clientsToSave.removeAll(client);
@@ -770,20 +778,23 @@ void KSMServer::deleteClient(KSMClient *client)
         handlePendingInteractions();
     }
     delete client;
-    if (state == Shutdown || state == Checkpoint || state == ClosingSubSession)
+    if (state == Shutdown || state == Checkpoint || state == ClosingSubSession) {
         completeShutdownOrCheckpoint();
-    if (state == Killing)
+    }
+    if (state == Killing) {
         completeKilling();
-    else if (state == KillingSubSession)
+    } else if (state == KillingSubSession) {
         completeKillingSubSession();
+    }
 }
 
 void KSMServer::newConnection(int /*socket*/)
 {
-    IceAcceptStatus status;
-    IceConn iceConn = IceAcceptConnection(((KSMListener *)sender())->listenObj, &status);
-    if (iceConn == nullptr)
+    IceAcceptStatus status = IceAcceptFailure;
+    auto iceConn = IceAcceptConnection(((KSMListener *)sender())->listenObj, &status);
+    if (!iceConn) {
         return;
+    }
 
     // This should be sufficient to hold all open file descriptors that are not connection watches. The rest we will
     // freely use to watch ICE connections.
@@ -833,17 +844,18 @@ void KSMServer::newConnection(int /*socket*/)
     }
 
     IceSetShutdownNegotiation(iceConn, false);
-    IceConnectStatus cstatus;
+    IceConnectStatus cstatus = IceConnectPending;
     while ((cstatus = IceConnectionStatus(iceConn)) == IceConnectPending) {
         (void)IceProcessMessages(iceConn, nullptr, nullptr);
     }
 
     if (cstatus != IceConnectAccepted) {
-        if (cstatus == IceConnectIOError)
+        if (cstatus == IceConnectIOError) {
             qCDebug(KSMSERVER) << "IO error opening ICE Connection!";
-        else
+        } else {
             qCDebug(KSMSERVER) << "ICE Connection rejected!";
-        (void)IceCloseConnection(iceConn);
+        }
+        std::ignore = IceCloseConnection(iceConn);
         return;
     }
 
@@ -853,8 +865,9 @@ void KSMServer::newConnection(int /*socket*/)
 
 QString KSMServer::currentSession()
 {
-    if (sessionGroup.startsWith(QLatin1String("Session: ")))
-        return sessionGroup.mid(9);
+    if (sessionGroup.startsWith(SESSION_PREFIX)) {
+        return sessionGroup.mid(SESSION_PREFIX.size());
+    }
     return QLatin1String(""); // empty, not null, since used for KConfig::setGroup // TODO does this comment make any sense?
 }
 
@@ -864,16 +877,19 @@ void KSMServer::discardSession()
     int count = config.readEntry("count", 0);
     foreach (KSMClient *c, clients) {
         QStringList discardCommand = c->discardCommand();
-        if (discardCommand.isEmpty())
+        if (discardCommand.isEmpty()) {
             continue;
+        }
         // check that non of the old clients used the exactly same
         // discardCommand before we execute it. This used to be the
         // case up to KDE and Qt < 3.1
         int i = 1;
-        while (i <= count && config.readPathEntry(QStringLiteral("discardCommand") + QString::number(i), QStringList()) != discardCommand)
+        while (i <= count && config.readPathEntry(QStringLiteral("discardCommand") + QString::number(i), QStringList()) != discardCommand) {
             i++;
-        if (i <= count)
+        }
+        if (i <= count) {
             executeCommand(discardCommand);
+        }
     }
 }
 
@@ -881,23 +897,26 @@ void KSMServer::storeSession()
 {
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
     config->reparseConfiguration(); // config may have changed in the KControl module
-    KConfigGroup generalGroup(config, "General");
+    KConfigGroup generalGroup(config, QStringLiteral("General"));
     excludeApps = generalGroup.readEntry("excludeApps").toLower().split(QRegularExpression(QStringLiteral("[,:]")), Qt::SkipEmptyParts);
     KConfigGroup configSessionGroup(config, sessionGroup);
     int count = configSessionGroup.readEntry("count", 0);
     for (int i = 1; i <= count; i++) {
-        QStringList discardCommand = configSessionGroup.readPathEntry(QLatin1String("discardCommand") + QString::number(i), QStringList());
-        if (discardCommand.isEmpty())
+        const auto discardCommand = configSessionGroup.readPathEntry(QLatin1String("discardCommand") + QString::number(i), QStringList());
+        if (discardCommand.isEmpty()) {
             continue;
+        }
         // check that non of the new clients uses the exactly same
         // discardCommand before we execute it. This used to be the
         // case up to KDE and Qt < 3.1
         QList<KSMClient *>::iterator it = clients.begin();
         QList<KSMClient *>::iterator const itEnd = clients.end();
-        while ((it != itEnd) && *it && (discardCommand != (*it)->discardCommand()))
+        while ((it != itEnd) && *it && (discardCommand != (*it)->discardCommand())) {
             ++it;
-        if ((it != itEnd) && *it)
+        }
+        if ((it != itEnd) && *it) {
             continue;
+        }
         executeCommand(discardCommand);
     }
     config->deleteGroup(sessionGroup); // ### does not work with global config object...
@@ -909,19 +928,22 @@ void KSMServer::storeSession()
     reply.waitForFinished(); // boo!
 
     foreach (KSMClient *c, clients) {
-        int restartHint = c->restartStyleHint();
-        if (restartHint == SmRestartNever)
+        const int restartHint = c->restartStyleHint();
+        if (restartHint == SmRestartNever) {
             continue;
-        QString program = c->program();
-        QStringList restartCommand = c->restartCommand();
-        if (program.isEmpty() && restartCommand.isEmpty())
+        }
+        const QString program = c->program();
+        const QStringList restartCommand = c->restartCommand();
+        if (program.isEmpty() && restartCommand.isEmpty()) {
             continue;
-        if (state == ClosingSubSession && !clientsToSave.contains(c))
+        }
+        if (state == ClosingSubSession && !clientsToSave.contains(c)) {
             continue;
+        }
 
         // 'program' might be (mostly) fullpath, or (sometimes) just the name.
         // 'name' is just the name.
-        QFileInfo info(program);
+        const QFileInfo info(program);
         const QString &name = info.fileName();
 
         if (excludeApps.contains(program.toLower()) || excludeApps.contains(name.toLower())) {
@@ -929,7 +951,7 @@ void KSMServer::storeSession()
         }
 
         count++;
-        QString n = QString::number(count);
+        const QString n = QString::number(count);
         cg.writeEntry(QStringLiteral("program") + n, program);
         cg.writeEntry(QStringLiteral("clientId") + n, c->clientId());
         cg.writeEntry(QStringLiteral("restartCommand") + n, restartCommand);
@@ -939,7 +961,7 @@ void KSMServer::storeSession()
     }
     cg.writeEntry("count", count);
 
-    KConfigGroup cg2(config, "General");
+    KConfigGroup cg2(config, QStringLiteral("General"));
 
     storeLegacySession(config.data());
     config->sync();
@@ -950,9 +972,11 @@ QStringList KSMServer::sessionList()
     QStringList sessions(QStringLiteral("default"));
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
     const QStringList groups = config->groupList();
-    for (QStringList::ConstIterator it = groups.constBegin(); it != groups.constEnd(); ++it)
-        if ((*it).startsWith(QLatin1String("Session: ")))
-            sessions << (*it).mid(9);
+    for (auto it = groups.constBegin(); it != groups.constEnd(); ++it) {
+        if ((*it).startsWith(SESSION_PREFIX)) {
+            sessions << (*it).mid(SESSION_PREFIX.size());
+        }
+    }
     return sessions;
 }
 
@@ -961,59 +985,15 @@ bool KSMServer::defaultSession() const
     return sessionGroup.isEmpty();
 }
 
-void KSMServer::setupShortcuts()
-{
-    if (KAuthorized::authorize(QStringLiteral("logout"))) {
-        KActionCollection *actionCollection = new KActionCollection(this);
-        actionCollection->setComponentDisplayName(i18n("Session Management"));
-        QAction *a;
-
-        // "With confirmation" actions
-        a = actionCollection->addAction(QStringLiteral("Log Out"));
-        a->setText(i18n("Log Out"));
-        KGlobalAccel::self()->setGlobalShortcut(a, QList<QKeySequence>() << (Qt::ALT | Qt::CTRL | Qt::Key_Delete));
-        connect(a, &QAction::triggered, this, &KSMServer::defaultLogout);
-
-        a = actionCollection->addAction(QStringLiteral("Shut Down"));
-        a->setText(i18n("Shut Down"));
-        KGlobalAccel::self()->setGlobalShortcut(a, QKeySequence());
-        connect(a, &QAction::triggered, this, &KSMServer::haltWithConfirmation);
-
-        a = actionCollection->addAction(QStringLiteral("Reboot"));
-        a->setText(i18n("Reboot"));
-        KGlobalAccel::self()->setGlobalShortcut(a, QKeySequence());
-        connect(a, &QAction::triggered, this, &KSMServer::rebootWithConfirmation);
-
-        // "Without confirmation" actions
-        a = actionCollection->addAction(QStringLiteral("Log Out Without Confirmation"));
-        a->setText(i18n("Log Out Without Confirmation"));
-        KGlobalAccel::self()->setGlobalShortcut(a, QKeySequence());
-        connect(a, &QAction::triggered, this, &KSMServer::logoutWithoutConfirmation);
-
-        a = actionCollection->addAction(QStringLiteral("Halt Without Confirmation"));
-        a->setText(i18n("Shut Down Without Confirmation"));
-        KGlobalAccel::self()->setGlobalShortcut(a, QKeySequence());
-        connect(a, &QAction::triggered, this, &KSMServer::haltWithoutConfirmation);
-
-        a = actionCollection->addAction(QStringLiteral("Reboot Without Confirmation"));
-        a->setText(i18n("Reboot Without Confirmation"));
-        KGlobalAccel::self()->setGlobalShortcut(a, QKeySequence());
-        connect(a, &QAction::triggered, this, &KSMServer::rebootWithoutConfirmation);
-    }
-}
-
 void KSMServer::setRestoreSession(const QString &sessionName)
 {
-    if (state != Idle)
+    if (state != Idle) {
         return;
-#ifdef KSMSERVER_STARTUP_DEBUG1
-    t.start();
-#endif
-
+    }
     qCDebug(KSMSERVER) << "KSMServer::restoreSession " << sessionName;
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
 
-    sessionGroup = QLatin1String("Session: ") + sessionName;
+    sessionGroup = SESSION_PREFIX + sessionName;
     KConfigGroup configSessionGroup(config, sessionGroup);
 
     int count = configSessionGroup.readEntry("count", 0);
@@ -1025,11 +1005,9 @@ void KSMServer::setRestoreSession(const QString &sessionName)
  */
 void KSMServer::startDefaultSession()
 {
-    if (state != Idle)
+    if (state != Idle) {
         return;
-#ifdef KSMSERVER_STARTUP_DEBUG1
-    t.start();
-#endif
+    }
     sessionGroup = QString();
 }
 
@@ -1047,7 +1025,7 @@ void KSMServer::restoreSession()
     state = KSMServer::Restoring;
 
     auto reply = m_kwinInterface->loadSession(currentSession());
-    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
+    auto watcher = new QDBusPendingCallWatcher(reply, this);
     connect(watcher, &QDBusPendingCallWatcher::finished, this, [this, reply](QDBusPendingCallWatcher *watcher) {
         watcher->deleteLater();
         if (reply.isError()) {
@@ -1060,7 +1038,7 @@ void KSMServer::restoreSession()
 
 void KSMServer::restoreSubSession(const QString &name)
 {
-    sessionGroup = QStringLiteral("SubSession: ") + name;
+    sessionGroup = SUBSESSION_PREFIX + name;
 
     KConfigGroup configSessionGroup(KSharedConfig::openConfig(), sessionGroup);
     int count = configSessionGroup.readEntry("count", 0);
@@ -1076,8 +1054,9 @@ void KSMServer::clientRegistered(const char * /* previousId */)
 
 void KSMServer::tryRestore()
 {
-    if (state != Restoring && state != RestoringSubSession)
+    if (state != Restoring && state != RestoringSubSession) {
         return;
+    }
     KConfigGroup config(KSharedConfig::openConfig(), sessionGroup);
 
     struct DontStartEntry {
@@ -1169,36 +1148,6 @@ void KSMServer::startupDone()
     state = Idle;
 }
 
-void KSMServer::defaultLogout()
-{
-    shutdown(KWorkSpace::ShutdownConfirmYes, KWorkSpace::ShutdownTypeDefault, KWorkSpace::ShutdownModeDefault);
-}
-
-void KSMServer::logoutWithoutConfirmation()
-{
-    shutdown(KWorkSpace::ShutdownConfirmNo, KWorkSpace::ShutdownTypeNone, KWorkSpace::ShutdownModeDefault);
-}
-
-void KSMServer::haltWithConfirmation()
-{
-    shutdown(KWorkSpace::ShutdownConfirmYes, KWorkSpace::ShutdownTypeHalt, KWorkSpace::ShutdownModeDefault);
-}
-
-void KSMServer::haltWithoutConfirmation()
-{
-    shutdown(KWorkSpace::ShutdownConfirmNo, KWorkSpace::ShutdownTypeHalt, KWorkSpace::ShutdownModeDefault);
-}
-
-void KSMServer::rebootWithConfirmation()
-{
-    shutdown(KWorkSpace::ShutdownConfirmYes, KWorkSpace::ShutdownTypeReboot, KWorkSpace::ShutdownModeDefault);
-}
-
-void KSMServer::rebootWithoutConfirmation()
-{
-    shutdown(KWorkSpace::ShutdownConfirmNo, KWorkSpace::ShutdownTypeReboot, KWorkSpace::ShutdownModeDefault);
-}
-
 void KSMServer::openSwitchUserDialog()
 {
     // this method exists only for compatibility. Users should ideally call this directly
