@@ -29,9 +29,8 @@ LocationUpdater::LocationUpdater(QObject *parent, const QList<QVariant> &)
 void LocationUpdater::resetLocator()
 {
     KConfigGroup group(m_configWatcher->config(), QStringLiteral("NightColor"));
-    const bool enabled = group.readEntry(QStringLiteral("Active"), false);
-    const QString mode = group.readEntry(QStringLiteral("Mode"), QStringLiteral("Automatic"));
-    if (m_adaptor->running() && enabled && mode == QStringLiteral("Automatic")) {
+    auto mode = group.readEntry(QStringLiteral("Mode"), 0);
+    if (m_adaptor->running() && mode == 0) {
         if (!m_locator) {
             m_locator = new ColorCorrect::Geolocator(this);
             connect(m_locator, &ColorCorrect::Geolocator::locationChanged, this, &LocationUpdater::sendLocation);
@@ -53,9 +52,9 @@ void LocationUpdater::sendLocation(double latitude, double longitude)
 void LocationUpdater::disableSelf()
 {
     QDBusConnection dbus = QDBusConnection::sessionBus();
-    QDBusMessage unloadMsg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kded5"),
+    QDBusMessage unloadMsg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kded6"),
                                                             QStringLiteral("/kded"),
-                                                            QStringLiteral("org.kde.kded5"),
+                                                            QStringLiteral("org.kde.kded6"),
                                                             QStringLiteral("unloadModule"));
     unloadMsg.setArguments({QVariant(QStringLiteral("colorcorrectlocationupdater"))});
     dbus.call(unloadMsg, QDBus::NoBlock);
