@@ -27,6 +27,7 @@ AbstractPlayerContainer::AbstractPlayerContainer(QObject *parent)
 AbstractPlayerContainer::~AbstractPlayerContainer()
 {
 }
+
 bool AbstractPlayerContainer::canControl() const
 {
     return m_canControl.value();
@@ -254,7 +255,7 @@ void PlayerContainer::setVolume(double value)
 
 void PlayerContainer::Next()
 {
-    Q_ASSERT(m_canGoNext.value());
+    Q_ASSERT_X(m_canGoNext.value(), Q_FUNC_INFO, qUtf8Printable(identity()));
     if (!m_canGoNext.value()) {
         return;
     }
@@ -269,7 +270,7 @@ void PlayerContainer::OpenUri(const QString &Uri)
 
 void PlayerContainer::Pause()
 {
-    Q_ASSERT(m_canPause.value());
+    Q_ASSERT_X(m_canPause.value(), Q_FUNC_INFO, qUtf8Printable(identity()));
     if (!m_canPause.value()) {
         return;
     }
@@ -278,7 +279,7 @@ void PlayerContainer::Pause()
 
 void PlayerContainer::Play()
 {
-    Q_ASSERT(m_canPlay.value());
+    Q_ASSERT_X(m_canPlay.value(), Q_FUNC_INFO, qUtf8Printable(identity()));
     if (!m_canPlay.value()) {
         return;
     }
@@ -287,8 +288,8 @@ void PlayerContainer::Play()
 
 void PlayerContainer::PlayPause()
 {
-    Q_ASSERT(m_canPlay.value());
-    Q_ASSERT(m_canPause.value());
+    Q_ASSERT_X(m_canPlay.value(), Q_FUNC_INFO, qUtf8Printable(identity()));
+    Q_ASSERT_X(m_canPause.value(), Q_FUNC_INFO, qUtf8Printable(identity()));
     if (!m_canPlay.value() || !m_canPause.value()) {
         return;
     }
@@ -297,7 +298,7 @@ void PlayerContainer::PlayPause()
 
 void PlayerContainer::Previous()
 {
-    Q_ASSERT(m_canGoPrevious.value());
+    Q_ASSERT_X(m_canGoPrevious.value(), Q_FUNC_INFO, qUtf8Printable(identity()));
     if (!m_canGoPrevious.value()) {
         return;
     }
@@ -307,7 +308,7 @@ void PlayerContainer::Previous()
 
 void PlayerContainer::Seek(qlonglong Offset)
 {
-    Q_ASSERT(m_canSeek.value());
+    Q_ASSERT_X(m_canSeek.value(), Q_FUNC_INFO, qUtf8Printable(identity()));
     if (!m_canSeek.value()) {
         return;
     }
@@ -316,7 +317,7 @@ void PlayerContainer::Seek(qlonglong Offset)
 
 void PlayerContainer::Stop()
 {
-    Q_ASSERT(m_canStop.value());
+    Q_ASSERT_X(m_canStop.value(), Q_FUNC_INFO, qUtf8Printable(identity()));
     if (!m_canStop.value()) {
         return;
     }
@@ -382,7 +383,7 @@ QStringList AbstractPlayerContainer::supportedUriSchemes() const
 
 void PlayerContainer::Quit()
 {
-    Q_ASSERT(m_canQuit.value());
+    Q_ASSERT_X(m_canQuit.value(), Q_FUNC_INFO, qUtf8Printable(identity()));
     if (!m_canQuit.value()) {
         return;
     }
@@ -390,7 +391,7 @@ void PlayerContainer::Quit()
 }
 void PlayerContainer::Raise()
 {
-    Q_ASSERT(m_canRaise.value());
+    Q_ASSERT_X(m_canRaise.value(), Q_FUNC_INFO, qUtf8Printable(identity()));
     if (!m_canRaise.value()) {
         return;
     }
@@ -501,14 +502,14 @@ void PlayerContainer::initBindings()
         if (!m_xesamTitle.value().isEmpty()) {
             return m_xesamTitle.value();
         }
-        const QString &xesamUrl = m_xesamUrl.value();
+        const QStringView xesamUrl{m_xesamUrl.value()};
         if (xesamUrl.isEmpty()) {
             return QString();
         }
         if (int lastSlashPos = xesamUrl.lastIndexOf(QLatin1Char('/')); lastSlashPos < 0 || lastSlashPos == xesamUrl.size() - 1) {
             return QString();
         } else {
-            const QString lastUrlPart = xesamUrl.sliced(lastSlashPos + 1);
+            const QStringView lastUrlPart = xesamUrl.sliced(lastSlashPos + 1);
             return QUrl::fromEncoded(lastUrlPart.toLatin1()).toString();
         }
     });
@@ -525,28 +526,26 @@ void PlayerContainer::initBindings()
         if (!m_xesamAlbum.value().isEmpty()) {
             return m_xesamAlbum.value();
         }
-        const QString &xesamUrl = m_xesamUrl.value();
+        const QStringView xesamUrl{m_xesamUrl.value()};
         if (!xesamUrl.startsWith(QLatin1String("file:///"))) {
             return QString();
         }
-        const QStringList urlParts = xesamUrl.split(QLatin1Char('/'));
+        const QList<QStringView> urlParts = xesamUrl.split(QLatin1Char('/'));
         if (urlParts.size() < 3) {
             return QString();
         }
         // if we play a local file without title and artist, show its containing folder instead
-        const auto lastFolderPathIt = std::next(urlParts.crbegin());
-        if (!lastFolderPathIt->isEmpty()) {
-            return *lastFolderPathIt;
+        if (auto lastFolderPathIt = std::next(urlParts.crbegin()); !lastFolderPathIt->isEmpty()) {
+            return QUrl::fromEncoded(lastFolderPathIt->toLatin1()).toString();
         }
         return QString();
     });
 
-    m_notifiers.reserve(2);
     auto callback = [this] {
         updatePosition();
     };
-    m_notifiers.emplace_back(m_rate.addNotifier(callback));
-    m_notifiers.emplace_back(m_playbackStatus.addNotifier(callback));
+    m_rateNotifier = m_rate.addNotifier(callback);
+    m_playbackStatusNotifier = m_playbackStatus.addNotifier(callback);
 }
 
 void PlayerContainer::updateFromMap(const QVariantMap &map)
@@ -678,8 +677,8 @@ void PlayerContainer::onGetPropsFinished(QDBusPendingCallWatcher *watcher)
     }
 
     if (propsReply.isError()) {
-        qCWarning(MPRIS2) << m_dbusAddress << "does not implement" << OrgFreedesktopDBusPropertiesInterface::staticInterfaceName() << "correctly"
-                          << "Error message was" << propsReply.error().name() << propsReply.error().message();
+        qCDebug(MPRIS2) << m_dbusAddress << "does not implement" << OrgFreedesktopDBusPropertiesInterface::staticInterfaceName() << "correctly"
+                        << "Error message was" << propsReply.error().name() << propsReply.error().message();
         m_fetchesPending = 0;
         Q_EMIT initialFetchFailed(this);
         return;
