@@ -10,22 +10,16 @@
 
 #include <KLocalizedString>
 
-#include <QCoreApplication>
 #include <QDBusArgument>
 #include <QDBusConnectionInterface>
 #include <QDBusInterface>
 #include <QDBusMetaType>
 #include <QDBusObjectPath>
 #include <QDBusReply>
+#include <QGuiApplication>
 
 #include "config-X11.h"
 #if HAVE_X11
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-#include <private/qtx11extras_p.h>
-#else
-#include <QX11Info>
-#endif
-
 #include <X11/Xauth.h>
 #include <X11/Xlib.h>
 #endif // HAVE_X11
@@ -73,8 +67,6 @@ struct NamedDBusObjectPath {
     QString name;
     QDBusObjectPath path;
 };
-Q_DECLARE_METATYPE(NamedDBusObjectPath)
-Q_DECLARE_METATYPE(QList<NamedDBusObjectPath>)
 
 // Marshall the NamedDBusObjectPath data into a D-Bus argument
 QDBusArgument &operator<<(QDBusArgument &argument, const NamedDBusObjectPath &namedPath)
@@ -98,7 +90,6 @@ struct NumberedDBusObjectPath {
     uint num;
     QDBusObjectPath path;
 };
-Q_DECLARE_METATYPE(NumberedDBusObjectPath)
 
 // Marshall the NumberedDBusObjectPath data into a D-Bus argument
 QDBusArgument &operator<<(QDBusArgument &argument, const NumberedDBusObjectPath &numberedPath)
@@ -856,11 +847,16 @@ void KDisplayManager::GDMAuthenticate()
 {
 #if HAVE_X11
     FILE *fp;
-    const char *dpy, *dnum, *dne;
+    const char *dpy = nullptr, *dnum, *dne;
     int dnl;
     Xauth *xau;
 
-    dpy = DisplayString(QX11Info::display());
+    if (auto instance = qobject_cast<QGuiApplication *>(QCoreApplication::instance())) {
+        if (auto nativeInterface = instance->nativeInterface<QNativeInterface::QX11Application>()) {
+            dpy = DisplayString(nativeInterface->display());
+        }
+    }
+
     if (!dpy) {
         dpy = ::getenv("DISPLAY");
         if (!dpy)
