@@ -14,22 +14,11 @@ if __name__ == '__main__':
 
     environ = os.environ.copy()
     environ["KWIN_WAYLAND_NO_PERMISSION_CHECKS"] = "1"
-    kwin_process = subprocess.Popen(["kwin_wayland", "--no-lockscreen", "--no-global-shortcuts", "--no-kactivities"], env = environ)
-    assert kwin_process.poll() is None
-
-    time.sleep(10)
-
-    test_environ = os.environ.copy()
-    test_environ["QT_QPA_PLATFORM"] = "wayland"
-    if os.path.exists(test_executable_path):
-        test_process = subprocess.Popen([test_executable_path], env = test_environ)
-    elif "KDECI_BUILD" in os.environ:
-        test_process = subprocess.Popen(["waylandtasksmodeltest"], env = test_environ) # Find in CMAKE_PREFIX_PATH
-    assert test_process.poll() is None
+    kwin_process = subprocess.Popen(["kwin_wayland", "--virtual", "--no-lockscreen", "--no-global-shortcuts", "--no-kactivities", "--exit-with-session", test_executable_path], env=environ)
 
     result: int = 1
     try:
-        result = test_process.wait(timeout=60)
+        result = kwin_process.wait(timeout=60)
     except subprocess.TimeoutExpired as e:
         print("Timeout", e)
     finally:
