@@ -528,27 +528,27 @@ void PanelView::positionPanel()
         break;
     }
 
-    // TODO: Make it X11-specific. It's still relevant on wayland because of popup positioning.
-    const QPoint pos = geometryByDistance(m_distance).topLeft();
-    setPosition(pos);
-    Q_EMIT geometryChanged();
-
     if (m_layerWindow) {
+        QMargins margins;
         LayerShellQt::Window::Anchors anchors;
 
         switch (containment()->location()) {
         case Plasma::Types::TopEdge:
             anchors.setFlag(LayerShellQt::Window::AnchorTop);
+            margins.setTop((-m_topFloatingPadding - m_bottomFloatingPadding) * (1 - m_floatingness));
             break;
         case Plasma::Types::LeftEdge:
             anchors.setFlag(LayerShellQt::Window::AnchorLeft);
+            margins.setLeft((-m_rightFloatingPadding - m_leftFloatingPadding) * (1 - m_floatingness));
             break;
         case Plasma::Types::RightEdge:
             anchors.setFlag(LayerShellQt::Window::AnchorRight);
+            margins.setRight((-m_rightFloatingPadding - m_leftFloatingPadding) * (1 - m_floatingness));
             break;
         case Plasma::Types::BottomEdge:
         default:
             anchors.setFlag(LayerShellQt::Window::AnchorBottom);
+            margins.setBottom((-m_topFloatingPadding - m_bottomFloatingPadding) * (1 - m_floatingness));
             break;
         }
 
@@ -556,35 +556,57 @@ void PanelView::positionPanel()
             switch (m_alignment) {
             case Qt::AlignLeft:
                 anchors.setFlag(LayerShellQt::Window::AnchorLeft);
+                if (m_lengthMode == PanelView::LengthMode::Custom) {
+                    margins.setLeft(margins.left() + m_offset);
+                }
                 break;
             case Qt::AlignCenter:
                 break;
             case Qt::AlignRight:
                 anchors.setFlag(LayerShellQt::Window::AnchorRight);
+                if (m_lengthMode == PanelView::LengthMode::Custom) {
+                    margins.setRight(margins.right() + m_offset);
+                }
                 break;
             }
+            if (m_lengthMode == PanelView::LengthMode::FillAvailable) {
+                anchors.setFlag(LayerShellQt::Window::AnchorLeft);
+                anchors.setFlag(LayerShellQt::Window::AnchorRight);
+            }
         } else {
             switch (m_alignment) {
             case Qt::AlignLeft:
                 anchors.setFlag(LayerShellQt::Window::AnchorTop);
+                if (m_lengthMode == PanelView::LengthMode::Custom) {
+                    margins.setTop(margins.top() + m_offset);
+                }
                 break;
             case Qt::AlignCenter:
                 break;
             case Qt::AlignRight:
                 anchors.setFlag(LayerShellQt::Window::AnchorBottom);
+                if (m_lengthMode == PanelView::LengthMode::Custom) {
+                    margins.setBottom(margins.bottom() + m_offset);
+                }
                 break;
             }
+            if (m_lengthMode == PanelView::LengthMode::FillAvailable) {
+                anchors.setFlag(LayerShellQt::Window::AnchorTop);
+                anchors.setFlag(LayerShellQt::Window::AnchorBottom);
+            }
         }
 
         m_layerWindow->setAnchors(anchors);
-        m_layerWindow->setMargins(QMargins((-m_rightFloatingPadding - m_leftFloatingPadding) * (1 - m_floatingness),
-                                           (-m_topFloatingPadding - m_bottomFloatingPadding) * (1 - m_floatingness),
-                                           (-m_rightFloatingPadding - m_leftFloatingPadding) * (1 - m_floatingness),
-                                           (-m_topFloatingPadding - m_bottomFloatingPadding) * (1 - m_floatingness)));
+        m_layerWindow->setMargins(margins);
         updateMask();
         requestUpdate();
     }
 
+    // TODO: Make it X11-specific. It's still relevant on wayland because of popup positioning.
+    const QPoint pos = geometryByDistance(m_distance).topLeft();
+    setPosition(pos);
+    Q_EMIT geometryChanged();
+
     KWindowEffects::slideWindow(this, slideLocation, -1);
 }
 
@@ -672,14 +694,15 @@ void PanelView::resizePanel()
         } else {
             s = QSize(m_screenToFollow->size().width(), totalThickness());
         }
-        setMinimumSize(s);
+        setMinimumSize(QSize(totalThickness(), totalThickness()));
         setMaximumSize(s);
         resize(s);
         return;
     } else if (m_lengthMode == PanelView::LengthMode::FitContent) {
         if (formFactor() == Plasma::Types::Vertical) {
-            s = QSize(totalThickness(),
-                      std::max(totalThickness(), std::min(m_screenToFollow->size().height(), m_contentLength + m_topFloatingPadding + m_bottomFloatingPadding)));
+            s = QSize(
+                totalThickness(),
+                std::max(totalThickness(), std::min(m_screenToFollow->size().height(), m_contentLength + m_topFloatingPadding + m_bottomFloatingPadding)));
         } else {
             s = QSize(std::max(totalThickness(), std::min(m_screenToFollow->size().width(), m_contentLength + m_leftFloatingPadding + m_rightFloatingPadding)),
                       totalThickness());
@@ -758,7 +781,9 @@ void PanelView::restore()
     // is safe to directly write during plasma startup, as there can be
     // resolution changes
     m_offset = readConfigValueWithFallBack("offset", m_offset);
-    if (m_alignment != Qt::AlignCenter) {
+    if (m_alignment == Qt::AlignCenter) {
+        m_offset = 0;
+    } else {
         m_offset = qMax(0, m_offset);
     }
 
@@ -827,7 +852,7 @@ void PanelView::showConfigurationInterface(Plasma::Applet *applet)
             m_appletConfigView->requestActivate();
             return;
         } else if (m_appletConfigView) {
-            delete m_appletConfigView;
+            m_appletConfigView->deleteLater(); // BUG 476968
         }
         m_appletConfigView = new PlasmaQuick::ConfigView(applet);
         m_appletConfigView->init();
@@ -1282,6 +1307,31 @@ bool PanelView::canSetStrut() const
 
 void PanelView::updateExclusiveZone()
 {
+    auto exclusiveMargin = [this] {
+        switch (location()) {
+        case Plasma::Types::TopEdge:
+            return m_layerWindow->margins().top();
+            break;
+        case Plasma::Types::LeftEdge:
+            return m_layerWindow->margins().left();
+            break;
+        case Plasma::Types::RightEdge:
+            return m_layerWindow->margins().right();
+            break;
+        case Plasma::Types::BottomEdge:
+        default:
+            return m_layerWindow->margins().bottom();
+            break;
+        }
+    };
+
+    if (containment() && containment()->isUserConfiguring() && m_layerWindow && m_layerWindow->exclusionZone() == 0) {
+        // We set the exclusive zone to make sure the ruler does not
+        // overlap with the panel regardless of the visibility mode;
+        // this won't be updated anymore as long as we are within
+        // the panel configuration.
+        m_layerWindow->setExclusiveZone(thickness() - exclusiveMargin());
+    }
     if (!containment() || containment()->isUserConfiguring() || !m_screenToFollow) {
         return;
     }
@@ -1289,7 +1339,7 @@ void PanelView::updateExclusiveZone()
     if (KWindowSystem::isPlatformWayland()) {
         switch (m_visibilityMode) {
         case NormalPanel:
-            m_layerWindow->setExclusiveZone(thickness() - m_layerWindow->margins().top());
+            m_layerWindow->setExclusiveZone(thickness() - exclusiveMargin());
             break;
         case AutoHide:
         case DodgeWindows:
@@ -1410,6 +1460,7 @@ void PanelView::refreshContainment()
             }
         }
     });
+    connect(containment(), &Plasma::Applet::userConfiguringChanged, this, &PanelView::updateExclusiveZone);
 }
 
 void PanelView::handleQmlStatusChange(QQmlComponent::Status status)
