@@ -10,22 +10,51 @@
 
 #include <QDateTime>
 #include <QDir>
+#include <QFileInfo>
 #include <QRandomGenerator>
 
 #include <KIO/OpenFileManagerWindowJob>
 
 #include <algorithm>
 
-SlideFilterModel::SlideFilterModel(QObject *parent)
+namespace
+{
+inline QString getLocalFilePath(const QModelIndex &modelIndex)
+{
+    return modelIndex.data(ImageRoles::PathRole).toUrl().toLocalFile();
+}
+
+inline QString getFilePathWithDir(const QFileInfo &fileInfo)
+{
+    return fileInfo.canonicalPath().append(QDir::separator());
+}
+}
+
+SlideFilterModel::SlideFilterModel(const QBindable<bool> &usedInConfig,
+                                   const QBindable<SortingMode::Mode> &sortingMode,
+                                   const QBindable<bool> &slideshowFoldersFirst,
+                                   QObject *parent)
     : QSortFilterProxyModel{parent}
-    , m_SortingMode{SortingMode::Random}
-    , m_SortingFoldersFirst{false}
-    , m_usedInConfig{false}
+    , m_SortingMode(sortingMode.makeBinding())
+    , m_SortingFoldersFirst(slideshowFoldersFirst.makeBinding())
+    , m_usedInConfig(usedInConfig.makeBinding())
     , m_random(m_randomDevice())
 {
     srand(time(nullptr));
     setSortCaseSensitivity(Qt::CaseSensitivity::CaseInsensitive);
-    connect(this, &SlideFilterModel::usedInConfigChanged, this, &SlideFilterModel::invalidateFilter);
+    m_usedInConfigNotifier = m_usedInConfig.addNotifier([this] {
+        invalidateRowsFilter();
+    });
+
+    auto sortCallback = [this] {
+        if (m_SortingMode == SortingMode::Random && !m_usedInConfig) {
+            buildRandomOrder();
+        }
+        QSortFilterProxyModel::invalidate();
+        sort(0);
+    };
+    m_SortingModeNotifier = m_SortingMode.addNotifier(sortCallback);
+    m_slideshowFoldersFirstNotifier = m_SortingFoldersFirst.addNotifier(sortCallback);
 }
 
 QHash<int, QByteArray> SlideFilterModel::roleNames() const
@@ -102,7 +131,7 @@ void SlideFilterModel::setSourceModel(QAbstractItemModel *sourceModel)
 
 bool SlideFilterModel::lessThan(const QModelIndex &source_left, const QModelIndex &source_right) const
 {
-    Qt::CaseSensitivity cs = Qt::CaseInsensitive;
+    constexpr Qt::CaseSensitivity cs = Qt::CaseInsensitive;
 
     switch (m_SortingMode) {
     case SortingMode::Random:
@@ -168,23 +197,13 @@ bool SlideFilterModel::lessThan(const QModelIndex &source_left, const QModelInde
     Q_UNREACHABLE();
 }
 
-void SlideFilterModel::setSortingMode(SortingMode::Mode slideshowMode, bool slideshowFoldersFirst)
-{
-    m_SortingMode = slideshowMode;
-    m_SortingFoldersFirst = slideshowFoldersFirst;
-    if (m_SortingMode == SortingMode::Random && !m_usedInConfig) {
-        buildRandomOrder();
-    }
-    QSortFilterProxyModel::invalidate();
-    sort(0);
-}
-
 void SlideFilterModel::invalidate()
 {
     if (m_SortingMode == SortingMode::Random && !m_usedInConfig) {
         std::shuffle(m_randomOrder.begin(), m_randomOrder.end(), m_random);
     }
     QSortFilterProxyModel::invalidate();
+    sort(0);
 }
 
 void SlideFilterModel::invalidateFilter()
@@ -214,13 +233,3 @@ void SlideFilterModel::buildRandomOrder()
         std::shuffle(m_randomOrder.begin(), m_randomOrder.end(), m_random);
     }
 }
-
-QString SlideFilterModel::getLocalFilePath(const QModelIndex &modelIndex) const
-{
-    return modelIndex.data(ImageRoles::PathRole).toUrl().toLocalFile();
-}
-
-QString SlideFilterModel::getFilePathWithDir(const QFileInfo &fileInfo) const
-{
-    return fileInfo.canonicalPath().append(QDir::separator());
-}
