@@ -25,11 +25,7 @@ public:
     ~FdoSelectionManager() override;
 
 protected:
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    bool nativeEventFilter(const QByteArray &eventType, void *message, long *result) override;
-#else
     bool nativeEventFilter(const QByteArray &eventType, void *message, qintptr *result) override;
-#endif
 
 private Q_SLOTS:
     void onClaimedOwnership();
