@@ -18,14 +18,11 @@
 #include <QGuiApplication>
 #include <QScreen>
 #include <QTimer>
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 #include <private/qtx11extras_p.h>
-#else
-#include <QX11Info>
-#endif
 
 #include <QBitmap>
 
+#include <KWindowInfo>
 #include <KWindowSystem>
 #include <netwm.h>
 
@@ -191,7 +188,7 @@ SNIProxy::~SNIProxy()
 
 void SNIProxy::update()
 {
-    const QImage image = getImageNonComposite();
+    QImage image = getImageNonComposite();
     if (image.isNull()) {
         qCDebug(SNIPROXY) << "No xembed icon for" << m_windowId << Title();
         return;
@@ -200,7 +197,7 @@ void SNIProxy::update()
     int w = image.width();
     int h = image.height();
 
-    m_pixmap = QPixmap::fromImage(image);
+    m_pixmap = QPixmap::fromImage(std::move(image));
     if (w > s_embedSize || h > s_embedSize) {
         qCDebug(SNIPROXY) << "Scaling pixmap of window" << m_windowId << Title() << "from w*h" << w << h;
         m_pixmap = m_pixmap.scaled(s_embedSize, s_embedSize, Qt::KeepAspectRatio, Qt::SmoothTransformation);
@@ -361,9 +358,8 @@ QImage SNIProxy::convertFromNative(xcb_image_t *xcbImage) const
 
     if (format == QImage::Format_RGB32 && xcbImage->bpp == 32) {
         QImage m = image.createHeuristicMask();
-        QBitmap mask(QPixmap::fromImage(m));
-        QPixmap p = QPixmap::fromImage(image);
-        p.setMask(mask);
+        QPixmap p = QPixmap::fromImage(std::move(image));
+        p.setMask(QBitmap::fromImage(std::move(m)));
         image = p.toImage();
     }
 
